changeset 88567:d67a992e35c6

(iso-latin-10): New coding system.
author Dave Love <fx@gnu.org>
date Sun, 19 May 2002 11:18:44 +0000
parents 2c3cb7fbba2a
children 6b39eddaf7dc
files lisp/language/romanian.el
diffstat 1 files changed, 15 insertions(+), 3 deletions(-) [+]
line wrap: on
line diff
--- a/lisp/language/romanian.el	Sun May 19 11:16:59 2002 +0000
+++ b/lisp/language/romanian.el	Sun May 19 11:18:44 2002 +0000
@@ -1,9 +1,9 @@
 ;;; romanian.el --- support for Romanian -*- coding: iso-latin-2; -*-
 
-;; Copyright (C) 1998 Free Software Foundation.
+;; Copyright (C) 1998, 2002 Free Software Foundation.
 
 ;; Author:    Dan Nicolaescu <done@ece.arizona.edu>
-;; Keywords: multilingual, Romanian
+;; Keywords: multilingual, Romanian, i18n
 
 ;; This file is part of GNU Emacs.
 
@@ -24,7 +24,7 @@
 
 ;;; Commentary:
 
 ;; Romanian ISO 8859-2 environment.
 
 ;;; Code:
 
@@ -41,6 +41,18 @@
 	      (documentation . t))
  '("European"))
 
+(define-coding-system 'iso-latin-10
+  "ISO 2022 based 8-bit encoding for Latin-10."
+  :coding-type 'charset
+  :mnemonic ?*
+  :charset-list '(iso-885916)
+  ;; not in current IANA list
+  ;; :mime-charset 'iso-885916
+  )
+
+(define-coding-system-alias 'iso-885916 'iso-latin-10)
+(define-coding-system-alias 'latin-10 'iso-latin-10)
+
 (provide 'romanian)
 
 ;;; romanian.el ends here
@@ -24,7 +24,7 @@
 ;;; Commentary:
 
-;; Romanian ISO 8859-2 environment.
+;; Romanian ISO 8859-2 environment plus 8859-16 coding system.
 
 ;;; Code: